[uClibc-cvs] uClibc/libc/sysdeps/linux/m68k/bits kernel_stat.h,1.2,1.3

Erik Andersen andersen at codepoet.org
Fri Jan 24 11:44:43 UTC 2003


Update of /var/cvs/uClibc/libc/sysdeps/linux/m68k/bits
In directory winder:/tmp/cvs-serv18234/libc/sysdeps/linux/m68k/bits

Modified Files:
	kernel_stat.h 
Log Message:
Ok, people are probably going to hate me for this...  This commit changes the
type of 'struct stat' and 'struct stat64' so they use consistant types.  

This change is the result of a bug I found while trying to use GNU tar.  The
problem was caused by our using kernel types within struct stat and trying to
directly compare these values with standard types.  Trying an 'if (a < b)' when
'a' is an 'unsigned long' and 'b' is an 'int' leads to very different results
then when comparing entities of the same type (i.e. time_t values)....
Grumble.  Nasty stuff, but I'm glad I got this out of the way now.

As a result of this fix, uClibc 0.9.17 will not be binary compatible with
earlier releases.  I have always warned people this can and will happen.
 -Erik


Index: kernel_stat.h
===================================================================
RCS file: /var/cvs/uClibc/libc/sysdeps/linux/m68k/bits/kernel_stat.h,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -d -r1.2 -r1.3
--- kernel_stat.h	25 Aug 2002 00:22:09 -0000	1.2
+++ kernel_stat.h	24 Jan 2003 11:44:09 -0000	1.3
@@ -2,11 +2,10 @@
 #define _BITS_STAT_STRUCT_H
 
 /* This file provides whatever this particular arch's kernel thinks 
  * struct stat should look like...  It turns out each arch has a 
  * different opinion on the subject... */
 
-#ifndef __USE_FILE_OFFSET64
-struct stat {
+struct kernel_stat {
 	unsigned short st_dev;
 	unsigned short __pad1;
 	unsigned long st_ino;
@@ -28,36 +27,8 @@
 	unsigned long  __unused4;
 	unsigned long  __unused5;
 };
-#else
-struct stat {
-	unsigned char	__pad0[6];
-	unsigned short	st_dev;
-	unsigned char	__pad1[2];
-#define STAT64_HAS_BROKEN_ST_INO	1
-	unsigned long	__st_ino;
-	unsigned int	st_mode;
-	unsigned int	st_nlink;
-	unsigned long	st_uid;
-	unsigned long	st_gid;
-	unsigned char	__pad2[6];
-	unsigned short	st_rdev;
-	unsigned char	__pad3[2];
-	long long	st_size;
-	unsigned long	st_blksize;
-	unsigned long	__pad4;		/* future possible st_blocks high bits */
-	unsigned long	st_blocks;	/* Number 512-byte blocks allocated. */
-	unsigned long	st_atime;
-	unsigned long	__pad5;
-	unsigned long	st_mtime;
-	unsigned long	__pad6;
-	unsigned long	st_ctime;
-	unsigned long	__pad7;		/* will be high 32 bits of ctime someday */
-	unsigned long long	st_ino;
-};
-#endif
 
-#ifdef __USE_LARGEFILE64
-struct stat64 {
+struct kernel_stat64 {
 	unsigned char	__pad0[6];
 	unsigned short	st_dev;
 	unsigned char	__pad1[2];
@@ -82,7 +53,6 @@
 	unsigned long	__pad7;		/* will be high 32 bits of ctime someday */
 	unsigned long long	st_ino;
 };
-#endif
 
 #endif	/*  _BITS_STAT_STRUCT_H */
 
@@ -2,11 +2,10 @@
 
 /* This file provides whatever this particular arch's kernel thinks 
- * struct stat should look like...  It turns out each arch has a 
+ * struct kernel_stat should look like...  It turns out each arch has a 
  * different opinion on the subject... */
 




More information about the uClibc-cvs mailing list